@@ -1,6 +1,6 @@
 __author__ = """Romain Picard"""
 __email__ = 'romain.picard@oakbits.com'
-__version__ = '0.8.0'
+__version__ = '0.13.2'
 
 from enum import Enum
 
@@ -14,5 +14,7 @@ from .mux import (
 )
 
 import rxsci.data as data
+import rxsci.error as error
 import rxsci.math as math
 import rxsci.operators as ops
+import rxsci.state as state
