@@ -1,3 +1,4 @@
+import typing
 import json
 import csv
 from collections import namedtuple
@@ -18,6 +19,8 @@ def parse_iso_date(i):
 
 
 def parse_int(i):
+    if len(i) == 0:
+        return None
     return int(i)
 
 
@@ -26,6 +29,8 @@ def parse_float(i):
 
 
 def parse_decimal(ii):
+    if len(ii) == 0:
+        return None
     try:
         s = ii.split(".")
         i = int(s[0])
@@ -42,28 +47,34 @@ def parse_decimal(ii):
 
 
 def type_parser(type_repr):
-    if type_repr in ['int']:
+    if type_repr in ['int', int]:
         return parse_int
-    if type_repr in ['float']:
+    if type_repr in ['float', float]:
         return parse_decimal
         #return parse_float
-    elif type_repr in ['bool']:
+    elif type_repr in ['bool', bool]:
         return lambda i: i == 'True'
     elif type_repr == 'posix_timestamp':
         return lambda i: datetime.fromtimestamp(int(i), tz=timezone.utc)
     elif type_repr == 'iso_datetime':
         return parse_iso_date
-    elif type_repr == 'str':
+    elif type_repr in ['str', str]:
         return lambda i: i
     else:
         raise TypeError("unknown column type: {}".format(type_repr))
 
 
 def create_schema_factory(dtype, schema_name='x'):
-    columns = [t[0] for t in dtype]
-    Item = namedtuple(schema_name, columns)
+    if not isinstance(dtype, list):
+        columns = [f for f in dtype._fields]
+        types = [dtype.__annotations__[f] for f in dtype._fields]
+        Item = dtype
+    else:
+        columns = [t[0] for t in dtype]
+        types = [i[1] for _, i in enumerate(dtype)]
+        Item = namedtuple(schema_name, columns)
     globals()[Item.__name__] = Item
-    return Item, columns
+    return Item, columns, types
 
 
 class CsvDataFile():
@@ -84,10 +95,17 @@ def merge_escape_parts(parts, separator):
     try:
         merged_parts = []
         agg = None
-        for t in parts:            
-            if len(t) > 0 and t[0] == '"' and t[-1] == '"' and agg is None:
+        for t in parts:
+            if t == '"':
+                if agg is None:
+                    agg = ['"']
+                else:
+                    agg.append('"')
+                    merged_parts.append(separator.join(agg))
+                    agg = None
+            elif len(t) > 0 and t[0] == '"' and t[-1] == '"' and t[-2] != '\\' and agg is None:
                 merged_parts.append(t)
-            elif len(t) > 0 and t[-1] == '"' and agg is not None:
+            elif len(t) > 0 and t[-1] == '"' and t[-2] != '\\' and agg is not None:
                 agg.append(t)
                 merged_parts.append(separator.join(agg))
                 agg = None
@@ -111,19 +129,23 @@ def create_line_parser(dtype, none_values=[], separator=",",
     ''' creates a parser for csv lines
 
     Args:
-        dtype: A list of (name, type) tuples.
+        dtype: A list of (name, type) tuples, or a typing.NamedTuple class.
         none_values: [Optional] Values to consider as None values
         separator: [Optional] Token used to separate each columns
         ignore_error: [Optional] when set to True, any line that does not
             match the provided number of columns raise an error an stop
             the parsing. When set to False, error lines are skipped.
+
+    Returns:
+        A Parsing function, that can parse text lines as specified in the
+        parameters.
     '''
-    Item, columns = create_schema_factory(dtype, schema_name)
-    columns_parser = [type_parser(i[1]) for index, i in enumerate(dtype)]
+    Item, columns, types = create_schema_factory(dtype, schema_name)
+    columns_parser = [type_parser(t) for t in types]
     columns_len = len(columns)
 
-    csv_file = CsvDataFile()
-    reader = csv.reader(csv_file)
+    #csv_file = CsvDataFile()
+    #reader = csv.reader(csv_file)
 
     def parse_column(index, i):
         return columns_parser[index](i)
@@ -131,6 +153,7 @@ def create_line_parser(dtype, none_values=[], separator=",",
     def split(line, separator):
         return line.split(separator)
 
+    """
     def parse_line_as_csv(line):
         csv_file.set_data(line)
         parts = next(reader)
@@ -165,30 +188,33 @@ def create_line_parser(dtype, none_values=[], separator=",",
 
         return Item(*parts)
         #return parts
+    """
 
     def parse_line(line):
-        parts = split(line, separator)
-        if len(parts) != columns_len:
-            parts = merge_escape_parts(parts, separator)
+        try:
+            parts = split(line, separator)
             if len(parts) != columns_len:
-                error = "invalid number of columns: expected {}, found {} on: {}".format(
-                    columns_len, len(parts), line)
-                if ignore_error is True:
-                    print("{}, \nignoring this line".format(error))
-                    return None
-                else:
+                parts = merge_escape_parts(parts, separator)
+                if len(parts) != columns_len:
+                    error = "invalid number of columns: expected {}, found {} on: {}".format(
+                        columns_len, len(parts), line)
                     raise ValueError(error)
 
-        for index, i in enumerate(parts):
-            if len(i) > 0 and i[0] == '"' and i[-1] == '"':
-                #i = i.strip('"')                
-                i = i[1:-1]
-                i = i.replace('\\"', '"')                
-            if i in none_values:
-                parts[index] = None
-            else:
-                parts[index] = parse_column(index, i)
+            for index, i in enumerate(parts):
+                if len(i) > 0 and i[0] == '"' and i[-1] == '"':
+                    i = i[1:-1]
+                    i = i.replace('\\"', '"')
+                if i in none_values:
+                    parts[index] = None
+                else:
+                    parts[index] = parse_column(index, i)
 
+        except Exception as e:
+            if ignore_error is True:
+                print("{}, \nignoring this line".format(e))
+                return None
+            else:
+                raise e
         #return item(*parsed_parts)
         return Item(*parts)
         #return parts
@@ -204,6 +230,7 @@ def load(parse_line, skip=0):
     ''' Loads a csv observable.
 
     The source observable must emit one csv row per item
+    The source must be an Observable.
 
     Args:
         parse_line: A line parser, e.g. created with create_line_parser
@@ -222,28 +249,23 @@ def load(parse_line, skip=0):
     return _load
 
 
-def load_from_file(filename, parse_line, skip=1, encoding=None,
-                   transport_params=None):
+def load_from_file(filename, parse_line, skip=1, encoding=None):
     ''' Loads a csv file.
 
     This factory loads the provided file and returns its content as an
     observable emitting one item per line.
 
     Args:
-        filename: Path of the file to read
+        filename: Path of the file to read or a file object
         parse_line: A line parser, e.g. created with create_line_parser
         skip: [Optional] Number of lines to skip before parsing
         encoding [Optional] Encoding used to parse the text content
-        transport_params: [Optional] When smart-open is used, then this
-            parameter is used to provide additional configuration information
 
     Returns:
         An observable of namedtuple items, where each key is a csv column
     '''
 
-    return file.read(
-        filename, size=64*1024, encoding=encoding,
-        transport_params=transport_params).pipe(
+    return file.read(filename, size=64*1024, encoding=encoding).pipe(
         line.unframe(),
         load(parse_line, skip=skip),
     )
@@ -253,6 +275,7 @@ def dump(header=True, separator=",", newline='\n'):
     ''' dumps an observable to csv.
 
     The source observable must emit one csv row per item
+    The source must be an Observable.
 
     Args:
         header: [Optional] indicates whether a header line must be added.
@@ -303,18 +326,17 @@ def dump(header=True, separator=",", newline='\n'):
 
 
 def dump_to_file(filename, header=True, separator=",",
-                 newline='\n', encoding=None,
-                 transport_params=None):
+                 newline='\n', encoding=None):
     ''' dumps each item to a csv file.
 
+    The source must be an Observable.
+
     Args:
-        filename: Path of the file to read
+        filename: Path of the file to read or a file object
         header: [Optional] indicates whether a header line must be added.
         separator: [Optional] Token used to separate each columns.
         newline: [Optional] Character(s) used for end of line.
         encoding [Optional] Encoding used to parse the text content
-        transport_params: [Optional] When smart-open is used, then this
-            parameter is used to provide additional configuration information
 
     Returns:
         An empty observable that completes on success when the source
@@ -322,7 +344,6 @@ def dump_to_file(filename, header=True, separator=",",
         while writing the csv file.
     '''
     def _dump_to_file(source):
-        print("dump transport params: {}".format(transport_params))
         mode = None
         if encoding is not None:
             mode = 'wb'
@@ -332,7 +353,6 @@ def dump_to_file(filename, header=True, separator=",",
             file.write(
                 file=filename,
                 mode=mode,
-                transport_params=transport_params
             ),
         )
 
