@@ -1,19 +1,22 @@
 from .assert_ import assert_, assert_1
 from .count import count
+from .flat_map import flat_map
 from .distinct import distinct
 from .distinct_until_changed import distinct_until_changed
 from .do_action import do_action
 from .filter import filter
 from .first import first
 from .group_by import group_by
+from .identity import identity
 from .last import last
 from .map import map
-from .multiplex import multiplex, demux_mux_observable
+from .multiplex import multiplex, mux_observable, demux_observable, demux_mux_observable
 from .on_subscribe import on_subscribe
-from .pandas import to_pandas
+from .pandas import from_pandas, to_pandas
 from .progress import progress
 from .starmap import starmap
 from .start_with import start_with
 from .scan import scan
+from .take import take
 from .tee_map import tee_map
 from .with_latest_from import with_latest_from
