@@ -12,7 +12,7 @@ def filter_mux(predicate):
                         if emit is True:
                             observer.on_next(i)
                     except Exception as e:
-                        observer.on_next(rs.OnErrorMux(i.key, e))
+                        observer.on_next(rs.OnErrorMux(i.key, e, i.store))
                 else:
                     observer.on_next(i)
 
@@ -31,6 +31,8 @@ def filter(predicate):
     """Filters the items of an observable sequence based on a
     predicate.
 
+    The source can be an Observable or a MuxObservable.
+
     .. marble::
         :alt: filter
 
@@ -45,9 +47,6 @@ def filter(predicate):
         predicate: A function to test each source item for a
             condition.
 
-    Source:
-        An Observable or a MuxObservable.
-
     Returns:
         An observable that emits items from the
         source observable that satisfy the condition. The type of the returned
