@@ -10,7 +10,6 @@ def mux_observable():
                 observer.on_next(rs.OnNextMux((0,), i))
 
             def on_error(e):
-                observer.on_next(rs.OnErrorMux((0,), e))
                 observer.on_error(e)
 
             def on_completed():
@@ -35,6 +34,8 @@ def demux_observable():
             def on_next(i):
                 if type(i) is rs.OnNextMux:
                     observer.on_next(i.item)
+                elif type(i) is rs.OnErrorMux:
+                    observer.on_error(i.error)
 
             return source.subscribe(
                 on_next=on_next,
@@ -52,14 +53,15 @@ def demux_mux_observable(outer_group):
         def on_subscribe(observer, scheduler):
             def on_next(i):
                 if type(i) is rs.OnNextMux:
-                    observer.on_next(rs.OnNextMux(i.key[1], i.item))
+                    observer.on_next(i._replace(key=i.key[1]))
+                elif type(i) is rs.OnErrorMux:
+                    observer.on_error(i.error)
+
                 '''
                 elif type(i) is rs.OnCreateMux:
                     observer.on_next(rs.OnCreateMux(i.key[1]))
                 elif type(i) is rs.OnCompletedMux:
                     observer.on_next(rs.OnCompletedMux(i.key[1]))
-                elif type(i) is rs.OnErrorMux:
-                    observer.on_next(rs.OnErrorMux(i.key[1], i.error))
                 else:
                     observer.on_next(TypeError("flatten_aggregate: unknow item type: {}".format(type(i))))
                 '''
@@ -70,7 +72,7 @@ def demux_mux_observable(outer_group):
             disposable = CompositeDisposable()
             disposable.add(outer_group.subscribe(
                 on_next=on_next_outer,
-                scheduler=scheduler,                
+                scheduler=scheduler,
             ))
             disposable.add(source.subscribe(
                 on_next=on_next,
@@ -87,16 +89,18 @@ def demux_mux_observable(outer_group):
 def multiplex(pipeline):
     '''Transforms an Observable to a MuxObservable
 
-    All operations done in pipeline operate on MuxObservable.
+    All operations done in pipeline then operate on a MuxObservable.
+    The source must be an Observable.
 
     Args:
         pipeline: The pipeline that will process the multiplexed items.
 
     Returns:
         An Observable where the source items have been multiplexed to a
-        MuxObservable, then processed by the pipeline transorfations, and
+        MuxObservable, then processed by the pipeline transformations, and
         finally de-multiplexed to an Observable.
     '''
+    pipeline = rx.pipe(*pipeline) if type(pipeline) is list else pipeline
     return rx.pipe(
         mux_observable(),
         pipeline,
