@@ -25,11 +25,17 @@ def _process_many(*args, connectable, zip, combine):
                                 has_next.append(False)
                     observer.on_next(x)
                 return
+
             elif isinstance(x, rs.OnCompletedMux):
                 if i == n-1:
                     observer.on_next(x)
+                    if zip is True or combine is True:
+                        base_index = x.key[0] * n
+                        queue[base_index+i] = None
+                        has_next[base_index+i] = False
                 return
-            elif isinstance(x, rs.OnErrorMux):
+
+            elif not isinstance(x, rs.OnNextMux):
                 observer.on_next(x)
                 return
 
@@ -45,9 +51,10 @@ def _process_many(*args, connectable, zip, combine):
                         try:
                             _queue = queue[base_index:base_index+n]
                             res = tuple(_queue)
-                            res = rs.OnNextMux(x.key, res)
+                            res = rs.OnNextMux(x.key, res, x.store)
                             for index in range(n):
                                 has_next[base_index+index] = False
+                                queue[base_index+index] = None
                         except Exception as ex:  # pylint: disable=broad-except
                             observer.on_error(ex)
                             return
@@ -57,7 +64,7 @@ def _process_many(*args, connectable, zip, combine):
                     try:
                         _queue = queue[base_index:base_index+n]
                         res = tuple(_queue)
-                        res = rs.OnNextMux(x.key, res)
+                        res = rs.OnNextMux(x.key, res, x.store)
                     except Exception as ex:  # pylint: disable=broad-except
                         observer.on_error(ex)
                         return
@@ -132,6 +139,8 @@ def tee_map(*args, join='zip'):
     observable. This operator allows to do multiple processing on the same
     source, and combine the results as a single tuple object.
 
+    The source can be an Observable or a MuxObservable.
+
     .. marble::
         :alt: tee_map
 
@@ -154,9 +163,6 @@ def tee_map(*args, join='zip'):
             emitted by each arg pipeline. If set to 'combine_latest', then
             the last value of each processing are combined.
 
-    Source:
-        An Observable or a MuxObservable
-
     Returns:
         An observable containing tuples of the items emitted by each branch of
         the tee.
@@ -173,6 +179,8 @@ def tee_map(*args, join='zip'):
     else:
         raise ValueError("tee_map join argument must be on of zip, merge, combine_latest")
 
+    args = [rx.pipe(*arg) if type(arg) is list else arg for arg in args]
+    print(args)
     def _tee_map(source):
         if isinstance(source, rs.MuxObservable):
             connectable = source.pipe(
