@@ -17,10 +17,13 @@ def test_start_with():
 
     rx.from_(source).pipe(
         rs.cast_as_mux_observable(),
-        rs.ops.start_with([-3, -2, -1, 0]),
+        rs.state.with_memory_store(
+            rs.ops.start_with([-3, -2, -1, 0]),
+        ),
     ).subscribe(
         on_next=actual_result.append)
 
+    actual_result = [r._replace(store=None) for r in actual_result]
     assert actual_result == [
         rs.OnCreateMux((1,)),
         rs.OnNextMux((1,), -3),
@@ -34,3 +37,15 @@ def test_start_with():
         rs.OnNextMux((1,), 5),
         rs.OnCompletedMux((1,)),
     ]
+
+
+def test_start_with_without_store():
+    actual_error = []
+
+    rx.from_([1, 2, 3, 4]).pipe(
+        rs.ops.start_with([0, -1])
+    ).subscribe(
+        on_error=actual_error.append,
+    )
+
+    assert type(actual_error[0]) is ValueError
